@@ -11,33 +11,26 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from magnumclient.common.apiclient import exceptions as mc_exc
 from magnumclient.v1 import client as magnum_client
 
 from heat.common import exception
 from heat.engine.clients import client_plugin
 from heat.engine import constraints
 
-try:
-    from magnumclient.common.apiclient import exceptions as mc_exc
-except ImportError:
-    # NOTE (duvarenkov): For magnumclient versions before 2.0.0.
-    from magnumclient.openstack.common.apiclient import exceptions as mc_exc
-
 CLIENT_NAME = 'magnum'
 
 
 class MagnumClientPlugin(client_plugin.ClientPlugin):
 
-    service_types = [CONTAINER] = ['container']
+    service_types = [CONTAINER] = ['container-infra']
 
     def _create(self):
-        endpoint_type = self._get_client_option(CLIENT_NAME, 'endpoint_type')
-        endpoint = self.url_for(service_type=self.CONTAINER,
-                                endpoint_type=endpoint_type)
-
+        interface = self._get_client_option(CLIENT_NAME, 'endpoint_type')
         args = {
-            'magnum_url': endpoint,
-            'input_auth_token': self.auth_token
+            'interface': interface,
+            'service_type': self.CONTAINER,
+            'session': self.context.keystone_session
         }
         client = magnum_client.Client(**args)
         return client
