@@ -17,8 +17,6 @@ import six
 import oslo_db.exception
 from oslo_log import log as logging
 
-from heat.common import exception
-from heat.common.i18n import _
 from heat.common import identifier
 from heat.objects import event as event_object
 
@@ -39,7 +37,7 @@ class Event(object):
         already in the database.
         """
         self.context = context
-        self.stack = stack
+        self._stack_identifier = stack.identifier()
         self.action = action
         self.status = status
         self.reason = reason
@@ -54,31 +52,12 @@ class Event(object):
         self.timestamp = timestamp
         self.id = id
 
-    @classmethod
-    def load(cls, context, event_id, event=None, stack=None):
-        """Retrieve an Event from the database."""
-        from heat.engine import stack as parser
-
-        ev = (event if event is not None else
-              event_object.Event.get_by_id(context, event_id))
-        if ev is None:
-            message = _('No event exists with id "%s"') % str(event_id)
-            raise exception.NotFound(message)
-
-        st = (stack if stack is not None else
-              parser.Stack.load(context, ev.stack_id))
-
-        return cls(context, st, ev.resource_action, ev.resource_status,
-                   ev.resource_status_reason, ev.physical_resource_id,
-                   ev.resource_properties, ev.resource_name,
-                   ev.resource_type, ev.uuid, ev.created_at, ev.id)
-
     def store(self):
         """Store the Event in the database."""
         ev = {
             'resource_name': self.resource_name,
             'physical_resource_id': self.physical_resource_id,
-            'stack_id': self.stack.id,
+            'stack_id': self._stack_identifier.stack_id,
             'resource_action': self.action,
             'resource_status': self.status,
             'resource_status_reason': self.reason,
@@ -135,7 +114,7 @@ class Event(object):
             return None
 
         res_id = identifier.ResourceIdentifier(
-            resource_name=self.resource_name, **self.stack.identifier())
+            resource_name=self.resource_name, **self._stack_identifier)
 
         return identifier.EventIdentifier(event_id=str(self.uuid), **res_id)
 
@@ -148,7 +127,7 @@ class Event(object):
             'payload': {
                 'resource_name': self.resource_name,
                 'physical_resource_id': self.physical_resource_id,
-                'stack_id': self.stack.id,
+                'stack_id': self._stack_identifier.stack_id,
                 'resource_action': self.action,
                 'resource_status': self.status,
                 'resource_status_reason': self.reason,
