@@ -10,7 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import collections
+import functools
 
 import six
 
@@ -22,27 +22,24 @@ from heat.engine import function
 from heat.engine.hot import functions as hot_funcs
 from heat.engine.hot import parameters
 from heat.engine import rsrc_defn
-from heat.engine import template
+from heat.engine import template_common
 
 
-_RESOURCE_KEYS = (
-    RES_TYPE, RES_PROPERTIES, RES_METADATA, RES_DEPENDS_ON,
-    RES_DELETION_POLICY, RES_UPDATE_POLICY,
-) = (
-    'type', 'properties', 'metadata', 'depends_on',
-    'deletion_policy', 'update_policy',
-)
-
-
-class HOTemplate20130523(template.Template):
+class HOTemplate20130523(template_common.CommonTemplate):
     """A Heat Orchestration Template format stack template."""
 
     SECTIONS = (
         VERSION, DESCRIPTION, PARAMETER_GROUPS,
-        PARAMETERS, RESOURCES, OUTPUTS, MAPPINGS
+        PARAMETERS, RESOURCES, OUTPUTS, MAPPINGS,
     ) = (
         'heat_template_version', 'description', 'parameter_groups',
-        'parameters', 'resources', 'outputs', '__undefined__'
+        'parameters', 'resources', 'outputs', '__undefined__',
+    )
+
+    OUTPUT_KEYS = (
+        OUTPUT_DESCRIPTION, OUTPUT_VALUE,
+    ) = (
+        'description', 'value',
     )
 
     SECTIONS_NO_DIRECT_ACCESS = set([PARAMETERS, VERSION])
@@ -54,18 +51,31 @@ class HOTemplate20130523(template.Template):
                             cfn_template.CfnTemplate.RESOURCES: RESOURCES,
                             cfn_template.CfnTemplate.OUTPUTS: OUTPUTS}
 
-    _RESOURCE_HOT_TO_CFN_ATTRS = {'type': 'Type',
-                                  'properties': 'Properties',
-                                  'metadata': 'Metadata',
-                                  'depends_on': 'DependsOn',
-                                  'deletion_policy': 'DeletionPolicy',
-                                  'update_policy': 'UpdatePolicy',
-                                  'description': 'Description',
-                                  'value': 'Value'}
+    _RESOURCE_KEYS = (
+        RES_TYPE, RES_PROPERTIES, RES_METADATA, RES_DEPENDS_ON,
+        RES_DELETION_POLICY, RES_UPDATE_POLICY, RES_DESCRIPTION,
+    ) = (
+        'type', 'properties', 'metadata', 'depends_on',
+        'deletion_policy', 'update_policy', 'description',
+    )
+
+    _RESOURCE_HOT_TO_CFN_ATTRS = {
+        RES_TYPE: cfn_template.CfnTemplate.RES_TYPE,
+        RES_PROPERTIES: cfn_template.CfnTemplate.RES_PROPERTIES,
+        RES_METADATA: cfn_template.CfnTemplate.RES_METADATA,
+        RES_DEPENDS_ON: cfn_template.CfnTemplate.RES_DEPENDS_ON,
+        RES_DELETION_POLICY: cfn_template.CfnTemplate.RES_DELETION_POLICY,
+        RES_UPDATE_POLICY: cfn_template.CfnTemplate.RES_UPDATE_POLICY,
+        RES_DESCRIPTION: cfn_template.CfnTemplate.RES_DESCRIPTION}
+
+    _HOT_TO_CFN_ATTRS = _RESOURCE_HOT_TO_CFN_ATTRS
+    _HOT_TO_CFN_ATTRS.update(
+        {OUTPUT_VALUE: cfn_template.CfnTemplate.OUTPUT_VALUE})
+
     functions = {
         'Fn::GetAZs': cfn_funcs.GetAZs,
         'get_param': hot_funcs.GetParam,
-        'get_resource': cfn_funcs.ResourceRef,
+        'get_resource': hot_funcs.GetResource,
         'Ref': cfn_funcs.Ref,
         'get_attr': hot_funcs.GetAttThenSelect,
         'Fn::Select': cfn_funcs.Select,
@@ -121,7 +131,8 @@ class HOTemplate20130523(template.Template):
             return self._translate_resources(the_section)
 
         if section == self.OUTPUTS:
-            return self._translate_outputs(the_section)
+            self.validate_section(self.OUTPUTS, self.OUTPUT_VALUE,
+                                  the_section, self.OUTPUT_KEYS)
 
         return the_section
 
@@ -135,25 +146,22 @@ class HOTemplate20130523(template.Template):
             else:
                 raise ke
 
-    def _translate_section(self, section, sub_section, data, mapping):
-        cfn_objects = {}
+    def validate_section(self, section, sub_section, data, allowed_keys):
         obj_name = section[:-1]
         err_msg = _('"%%s" is not a valid keyword inside a %s '
                     'definition') % obj_name
+        args = {'object_name': obj_name, 'sub_section': sub_section}
+        message = _('Each %(object_name)s must contain a '
+                    '%(sub_section)s key.') % args
         for name, attrs in sorted(data.items()):
-            cfn_object = {}
-
             if not attrs:
-                args = {'object_name': obj_name, 'sub_section': sub_section}
-                message = _('Each %(object_name)s must contain a '
-                            '%(sub_section)s key.') % args
                 raise exception.StackValidationFailed(message=message)
             try:
                 for attr, attr_value in six.iteritems(attrs):
-                    cfn_attr = self._translate(attr, mapping, err_msg)
-                    cfn_object[cfn_attr] = attr_value
-
-                cfn_objects[name] = cfn_object
+                    if attr not in allowed_keys:
+                        raise KeyError(err_msg % attr)
+                if sub_section not in attrs:
+                    raise exception.StackValidationFailed(message=message)
             except AttributeError:
                 message = _('"%(section)s" must contain a map of '
                             '%(obj_name)s maps. Found a [%(_type)s] '
@@ -165,28 +173,36 @@ class HOTemplate20130523(template.Template):
                 # an invalid keyword was found
                 raise exception.StackValidationFailed(message=e.args[0])
 
+    def _translate_section(self, section, sub_section, data, mapping):
+
+        self.validate_section(section, sub_section, data, mapping)
+
+        cfn_objects = {}
+        for name, attrs in sorted(data.items()):
+            cfn_object = {}
+
+            for attr, attr_value in six.iteritems(attrs):
+                cfn_attr = mapping[attr]
+                if cfn_attr is not None:
+                    cfn_object[cfn_attr] = attr_value
+
+            cfn_objects[name] = cfn_object
+
         return cfn_objects
 
     def _translate_resources(self, resources):
         """Get the resources of the template translated into CFN format."""
 
-        return self._translate_section('resources', 'type', resources,
+        return self._translate_section(self.RESOURCES, self.RES_TYPE,
+                                       resources,
                                        self._RESOURCE_HOT_TO_CFN_ATTRS)
 
     def get_section_name(self, section):
         cfn_to_hot_attrs = dict(
-            zip(six.itervalues(self._RESOURCE_HOT_TO_CFN_ATTRS),
-                six.iterkeys(self._RESOURCE_HOT_TO_CFN_ATTRS)))
+            zip(six.itervalues(self._HOT_TO_CFN_ATTRS),
+                six.iterkeys(self._HOT_TO_CFN_ATTRS)))
         return cfn_to_hot_attrs.get(section, section)
 
-    def _translate_outputs(self, outputs):
-        """Get the outputs of the template translated into CFN format."""
-        HOT_TO_CFN_ATTRS = {'description': 'Description',
-                            'value': 'Value'}
-
-        return self._translate_section('outputs', 'value', outputs,
-                                       HOT_TO_CFN_ATTRS)
-
     def param_schemata(self, param_defaults=None):
         parameter_section = self.t.get(self.PARAMETERS) or {}
         pdefaults = param_defaults or {}
@@ -203,79 +219,44 @@ class HOTemplate20130523(template.Template):
                                         user_params=user_params,
                                         param_defaults=param_defaults)
 
-    def validate_resource_definitions(self, stack):
-        resources = self.t.get(self.RESOURCES) or {}
-        allowed_keys = set(_RESOURCE_KEYS)
-
-        try:
-            for name, snippet in resources.items():
-                data = self.parse(stack, snippet)
-
-                if not self.validate_resource_key_type(RES_TYPE,
-                                                       six.string_types,
-                                                       'string',
-                                                       allowed_keys,
-                                                       name, data):
-                    args = {'name': name, 'type_key': RES_TYPE}
-                    msg = _('Resource %(name)s is missing '
-                            '"%(type_key)s"') % args
-                    raise KeyError(msg)
-
-                self.validate_resource_key_type(
-                    RES_PROPERTIES,
-                    (collections.Mapping, function.Function),
-                    'object', allowed_keys, name, data)
-                self.validate_resource_key_type(
-                    RES_METADATA,
-                    (collections.Mapping, function.Function),
-                    'object', allowed_keys, name, data)
-                self.validate_resource_key_type(
-                    RES_DEPENDS_ON,
-                    collections.Sequence,
-                    'list or string', allowed_keys, name, data)
-                self.validate_resource_key_type(
-                    RES_DELETION_POLICY,
-                    (six.string_types, function.Function),
-                    'string', allowed_keys, name, data)
-                self.validate_resource_key_type(
-                    RES_UPDATE_POLICY,
-                    (collections.Mapping, function.Function),
-                    'object', allowed_keys, name, data)
-        except (TypeError, ValueError) as ex:
-            raise exception.StackValidationFailed(message=six.text_type(ex))
-
     def resource_definitions(self, stack):
         resources = self.t.get(self.RESOURCES) or {}
-        parsed_resources = self.parse(stack, resources)
-        return dict((name, self.rsrc_defn_from_snippet(name, data))
-                    for name, data in parsed_resources.items())
+        conditions = self.conditions(stack)
 
-    @staticmethod
-    def rsrc_defn_from_snippet(name, data):
-        depends = data.get(RES_DEPENDS_ON)
-        if isinstance(depends, six.string_types):
-            depends = [depends]
+        valid_keys = frozenset(self._RESOURCE_KEYS)
 
-        deletion_policy = function.resolve(data.get(RES_DELETION_POLICY))
-        if deletion_policy is not None:
-            if deletion_policy not in six.iterkeys(
-                    HOTemplate20130523.deletion_policies):
-                msg = _('Invalid deletion policy "%s"') % deletion_policy
-                raise exception.StackValidationFailed(message=msg)
-            else:
-                deletion_policy = HOTemplate20130523.deletion_policies[
-                    deletion_policy]
-        kwargs = {
-            'resource_type': data.get(RES_TYPE),
-            'properties': data.get(RES_PROPERTIES),
-            'metadata': data.get(RES_METADATA),
-            'depends': depends,
-            'deletion_policy': deletion_policy,
-            'update_policy': data.get(RES_UPDATE_POLICY),
-            'description': None
-        }
+        def defns():
+            for name, snippet in six.iteritems(resources):
+                try:
+                    invalid_keys = set(snippet) - valid_keys
+                    if invalid_keys:
+                        raise ValueError(_('Invalid keyword(s) inside a '
+                                           'resource definition: '
+                                           '%s') % ', '.join(invalid_keys))
 
-        return rsrc_defn.ResourceDefinition(name, **kwargs)
+                    defn_data = dict(self._rsrc_defn_args(stack, name,
+                                                          snippet))
+                except (TypeError, ValueError, KeyError) as ex:
+                    msg = six.text_type(ex)
+                    raise exception.StackValidationFailed(message=msg)
+
+                defn = rsrc_defn.ResourceDefinition(name, **defn_data)
+                cond_name = defn.condition()
+
+                if cond_name is not None:
+                    try:
+                        enabled = conditions.is_enabled(cond_name)
+                    except ValueError as exc:
+                        path = [self.RESOURCES, name, self.RES_CONDITION]
+                        message = six.text_type(exc)
+                        raise exception.StackValidationFailed(path=path,
+                                                              message=message)
+                    if not enabled:
+                        continue
+
+                yield name, defn
+
+        return dict(defns())
 
     def add_resource(self, definition, name=None):
         if name is None:
@@ -291,14 +272,14 @@ class HOTemplate20141016(HOTemplate20130523):
         'get_attr': hot_funcs.GetAtt,
         'get_file': hot_funcs.GetFile,
         'get_param': hot_funcs.GetParam,
-        'get_resource': cfn_funcs.ResourceRef,
+        'get_resource': hot_funcs.GetResource,
         'list_join': hot_funcs.Join,
         'resource_facade': hot_funcs.ResourceFacade,
         'str_replace': hot_funcs.Replace,
 
         'Fn::Select': cfn_funcs.Select,
 
-        # functions removed from 20130523
+        # functions removed from 2014-10-16
         'Fn::GetAZs': hot_funcs.Removed,
         'Fn::Join': hot_funcs.Removed,
         'Fn::Split': hot_funcs.Removed,
@@ -312,11 +293,10 @@ class HOTemplate20141016(HOTemplate20130523):
 
 class HOTemplate20150430(HOTemplate20141016):
     functions = {
-        'digest': hot_funcs.Digest,
         'get_attr': hot_funcs.GetAtt,
         'get_file': hot_funcs.GetFile,
         'get_param': hot_funcs.GetParam,
-        'get_resource': cfn_funcs.ResourceRef,
+        'get_resource': hot_funcs.GetResource,
         'list_join': hot_funcs.Join,
         'repeat': hot_funcs.Repeat,
         'resource_facade': hot_funcs.ResourceFacade,
@@ -324,7 +304,10 @@ class HOTemplate20150430(HOTemplate20141016):
 
         'Fn::Select': cfn_funcs.Select,
 
-        # functions removed from 20130523
+        # functions added in 2015-04-30
+        'digest': hot_funcs.Digest,
+
+        # functions removed from 2014-10-16
         'Fn::GetAZs': hot_funcs.Removed,
         'Fn::Join': hot_funcs.Removed,
         'Fn::Split': hot_funcs.Removed,
@@ -338,23 +321,25 @@ class HOTemplate20150430(HOTemplate20141016):
 
 class HOTemplate20151015(HOTemplate20150430):
     functions = {
-        'digest': hot_funcs.Digest,
         'get_attr': hot_funcs.GetAttAllAttributes,
         'get_file': hot_funcs.GetFile,
         'get_param': hot_funcs.GetParam,
-        'get_resource': cfn_funcs.ResourceRef,
+        'get_resource': hot_funcs.GetResource,
         'list_join': hot_funcs.JoinMultiple,
         'repeat': hot_funcs.Repeat,
         'resource_facade': hot_funcs.ResourceFacade,
         'str_replace': hot_funcs.ReplaceJson,
 
-        # functions added since 20150430
+        # functions added in 2015-04-30
+        'digest': hot_funcs.Digest,
+
+        # functions added in 2015-10-15
         'str_split': hot_funcs.StrSplit,
 
-        # functions removed from 20150430
+        # functions removed from 2015-10-15
         'Fn::Select': hot_funcs.Removed,
 
-        # functions removed from 20130523
+        # functions removed from 2014-10-16
         'Fn::GetAZs': hot_funcs.Removed,
         'Fn::Join': hot_funcs.Removed,
         'Fn::Split': hot_funcs.Removed,
@@ -368,26 +353,28 @@ class HOTemplate20151015(HOTemplate20150430):
 
 class HOTemplate20160408(HOTemplate20151015):
     functions = {
-        'digest': hot_funcs.Digest,
         'get_attr': hot_funcs.GetAttAllAttributes,
         'get_file': hot_funcs.GetFile,
         'get_param': hot_funcs.GetParam,
-        'get_resource': cfn_funcs.ResourceRef,
+        'get_resource': hot_funcs.GetResource,
         'list_join': hot_funcs.JoinMultiple,
         'repeat': hot_funcs.Repeat,
         'resource_facade': hot_funcs.ResourceFacade,
         'str_replace': hot_funcs.ReplaceJson,
 
-        # functions added since 20151015
-        'map_merge': hot_funcs.MapMerge,
+        # functions added in 2015-04-30
+        'digest': hot_funcs.Digest,
 
-        # functions added since 20150430
+        # functions added in 2015-10-15
         'str_split': hot_funcs.StrSplit,
 
-        # functions removed from 20150430
+        # functions added in 2016-04-08
+        'map_merge': hot_funcs.MapMerge,
+
+        # functions removed from 2015-10-15
         'Fn::Select': hot_funcs.Removed,
 
-        # functions removed from 20130523
+        # functions removed from 2014-10-16
         'Fn::GetAZs': hot_funcs.Removed,
         'Fn::Join': hot_funcs.Removed,
         'Fn::Split': hot_funcs.Removed,
@@ -397,3 +384,128 @@ class HOTemplate20160408(HOTemplate20151015):
         'Fn::ResourceFacade': hot_funcs.Removed,
         'Ref': hot_funcs.Removed,
     }
+
+
+class HOTemplate20161014(HOTemplate20160408):
+
+    CONDITIONS = 'conditions'
+    SECTIONS = HOTemplate20160408.SECTIONS + (CONDITIONS,)
+
+    SECTIONS_NO_DIRECT_ACCESS = (HOTemplate20160408.SECTIONS_NO_DIRECT_ACCESS |
+                                 set([CONDITIONS]))
+
+    _CFN_TO_HOT_SECTIONS = HOTemplate20160408._CFN_TO_HOT_SECTIONS
+    _CFN_TO_HOT_SECTIONS.update({
+        cfn_template.CfnTemplate.CONDITIONS: CONDITIONS})
+
+    _EXTRA_RES_KEYS = (
+        RES_EXTERNAL_ID, RES_CONDITION
+    ) = (
+        'external_id', 'condition'
+    )
+    _RESOURCE_KEYS = HOTemplate20160408._RESOURCE_KEYS + _EXTRA_RES_KEYS
+
+    _RESOURCE_HOT_TO_CFN_ATTRS = HOTemplate20160408._RESOURCE_HOT_TO_CFN_ATTRS
+    _RESOURCE_HOT_TO_CFN_ATTRS.update({
+        RES_EXTERNAL_ID: None,
+        RES_CONDITION: cfn_template.CfnTemplate.RES_CONDITION,
+    })
+
+    OUTPUT_CONDITION = 'condition'
+    OUTPUT_KEYS = HOTemplate20160408.OUTPUT_KEYS + (OUTPUT_CONDITION,)
+
+    deletion_policies = {
+        'Delete': rsrc_defn.ResourceDefinition.DELETE,
+        'Retain': rsrc_defn.ResourceDefinition.RETAIN,
+        'Snapshot': rsrc_defn.ResourceDefinition.SNAPSHOT,
+
+        # aliases added in 2016-10-14
+        'delete': rsrc_defn.ResourceDefinition.DELETE,
+        'retain': rsrc_defn.ResourceDefinition.RETAIN,
+        'snapshot': rsrc_defn.ResourceDefinition.SNAPSHOT,
+    }
+
+    functions = {
+        'get_attr': hot_funcs.GetAttAllAttributes,
+        'get_file': hot_funcs.GetFile,
+        'get_param': hot_funcs.GetParam,
+        'get_resource': hot_funcs.GetResource,
+        'list_join': hot_funcs.JoinMultiple,
+        'repeat': hot_funcs.RepeatWithMap,
+        'resource_facade': hot_funcs.ResourceFacade,
+        'str_replace': hot_funcs.ReplaceJson,
+
+        # functions added in 2015-04-30
+        'digest': hot_funcs.Digest,
+
+        # functions added in 2015-10-15
+        'str_split': hot_funcs.StrSplit,
+
+        # functions added in 2016-04-08
+        'map_merge': hot_funcs.MapMerge,
+
+        # functions added in 2016-10-14
+        'yaql': hot_funcs.Yaql,
+        'map_replace': hot_funcs.MapReplace,
+        'if': hot_funcs.If,
+
+        # functions removed from 2015-10-15
+        'Fn::Select': hot_funcs.Removed,
+
+        # functions removed from 2014-10-16
+        'Fn::GetAZs': hot_funcs.Removed,
+        'Fn::Join': hot_funcs.Removed,
+        'Fn::Split': hot_funcs.Removed,
+        'Fn::Replace': hot_funcs.Removed,
+        'Fn::Base64': hot_funcs.Removed,
+        'Fn::MemberListToMap': hot_funcs.Removed,
+        'Fn::ResourceFacade': hot_funcs.Removed,
+        'Ref': hot_funcs.Removed,
+    }
+
+    condition_functions = {
+        'get_param': hot_funcs.GetParam,
+        'equals': hot_funcs.Equals,
+        'not': hot_funcs.Not,
+        'and': hot_funcs.And,
+        'or': hot_funcs.Or
+    }
+
+    def __init__(self, tmpl, template_id=None, files=None, env=None):
+        super(HOTemplate20161014, self).__init__(
+            tmpl, template_id, files, env)
+
+        self._parser_condition_functions = {}
+        for n, f in six.iteritems(self.functions):
+            if not isinstance(f, hot_funcs.Removed):
+                self._parser_condition_functions[n] = function.Invalid
+            else:
+                self._parser_condition_functions[n] = f
+        self._parser_condition_functions.update(self.condition_functions)
+        self.merge_sections = [self.PARAMETERS, self.CONDITIONS]
+
+    def _get_condition_definitions(self):
+        return self.t.get(self.CONDITIONS, {})
+
+    def _rsrc_defn_args(self, stack, name, data):
+        for arg in super(HOTemplate20161014, self)._rsrc_defn_args(stack,
+                                                                   name,
+                                                                   data):
+            yield arg
+
+        parse = functools.partial(self.parse, stack)
+        parse_cond = functools.partial(self.parse_condition, stack)
+
+        yield ('external_id',
+               self._parse_resource_field(self.RES_EXTERNAL_ID,
+                                          (six.string_types,
+                                           function.Function),
+                                          'string',
+                                          name, data, parse))
+
+        yield ('condition',
+               self._parse_resource_field(self.RES_CONDITION,
+                                          (six.string_types, bool,
+                                           function.Function),
+                                          'string_or_boolean',
+                                          name, data, parse_cond))
