@@ -11,14 +11,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
 from oslo_serialization import jsonutils
 import six
 
 from heat.common import context
 from heat.common import exception
 from heat.common.i18n import _
-from heat.common.i18n import _LE
 from heat.common import template_format
 from heat.engine import attributes
 from heat.engine import environment
@@ -27,8 +25,6 @@ from heat.engine import properties
 from heat.engine import resource
 from heat.engine import template
 
-LOG = logging.getLogger(__name__)
-
 
 class RemoteStack(resource.Resource):
     """A Resource representing a stack.
@@ -118,7 +114,8 @@ class RemoteStack(resource.Resource):
 
         # Build RequestContext from existing one
         dict_ctxt = self.context.to_dict()
-        dict_ctxt.update({'region_name': self._region_name})
+        dict_ctxt.update({'region_name': self._region_name,
+                          'overwrite': False})
         self._local_context = context.RequestContext.from_dict(dict_ctxt)
         return self._local_context
 
@@ -153,7 +150,6 @@ class RemoteStack(resource.Resource):
             self.heat().stacks.validate(**args)
         except Exception as ex:
             exc_info = dict(region=self._region_name, exc=six.text_type(ex))
-            LOG.error(_LE('exception: %s'), type(ex))
             msg = _('Failed validating stack template using Heat endpoint at '
                     'region "%(region)s" due to "%(exc)s"') % exc_info
             raise exception.StackValidationFailed(message=msg)
@@ -217,7 +213,7 @@ class RemoteStack(resource.Resource):
         # If resource is in CHECK_FAILED state, raise UpdateReplace
         # to replace the failed stack.
         if self.state == (self.CHECK, self.FAILED):
-            raise exception.UpdateReplace(self)
+            raise resource.UpdateReplace(self)
 
         # Always issue an update to the remote stack and let the individual
         # resources in it decide if they need updating.
@@ -227,11 +223,8 @@ class RemoteStack(resource.Resource):
         # Always issue an update to the remote stack and let the individual
         # resources in it decide if they need updating.
         if self.resource_id:
-            snippet = json_snippet.get('Properties', {})
-            self.properties = properties.Properties(self.properties_schema,
-                                                    snippet,
-                                                    function.resolve,
-                                                    self.name)
+            self.properties = json_snippet.properties(self.properties_schema,
+                                                      self.context)
 
             params = self.properties[self.PARAMETERS]
             env = environment.get_child_environment(self.stack.env, params)
