@@ -13,6 +13,7 @@
 
 from oslo_log import log as logging
 
+from heat.common import exception
 from heat.common.i18n import _
 from heat.common.i18n import _LW
 from heat.engine import attributes
@@ -72,7 +73,11 @@ class CronTrigger(resource.Resource):
             schema={
                 WORKFLOW_NAME: properties.Schema(
                     properties.Schema.STRING,
-                    _('Name of the workflow.')
+                    _('Name of the workflow.'),
+                    required=True,
+                    constraints=[
+                        constraints.CustomConstraint('mistral.workflow')
+                    ]
                 ),
                 WORKFLOW_INPUT: properties.Schema(
                     properties.Schema.MAP,
@@ -105,6 +110,13 @@ class CronTrigger(resource.Resource):
 
     entity = 'cron_triggers'
 
+    def validate(self):
+        super(CronTrigger, self).validate()
+        if not (self.properties[self.PATTERN]
+                or self.properties[self.FIRST_TIME]):
+            raise exception.PropertyUnspecifiedError(self.PATTERN,
+                                                     self.FIRST_TIME)
+
     def _cron_trigger_name(self):
         return self.properties.get(self.NAME) or self.physical_resource_name()
 
@@ -129,13 +141,6 @@ class CronTrigger(resource.Resource):
         elif name == self.REMAINING_EXECUTIONS:
             return trigger.remaining_executions
 
-    # TODO(tlashchova): remove this method when mistralclient>1.0.0 is used.
-    def _show_resource(self):
-        cron_trigger = self.client().cron_triggers.get(self.resource_id)
-        if hasattr(cron_trigger, 'to_dict'):
-            super(CronTrigger, self)._show_resource()
-        return cron_trigger._data
-
     def get_live_state(self, resource_properties):
         # Currently mistral just deletes cron trigger that was executed
         # (i.e. remaining execution is reached zero). In this case we can't
