@@ -13,6 +13,7 @@
 
 import itertools
 
+import eventlet
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import netutils
@@ -21,9 +22,7 @@ import retrying
 from heat.common import exception
 from heat.common.i18n import _
 from heat.common.i18n import _LI
-
 from heat.engine import resource
-
 from heat.engine.resources.openstack.neutron import port as neutron_port
 
 LOG = logging.getLogger(__name__)
@@ -36,6 +35,7 @@ class ServerNetworkMixin(object):
         port = network.get(self.NETWORK_PORT)
         subnet = network.get(self.NETWORK_SUBNET)
         fixed_ip = network.get(self.NETWORK_FIXED_IP)
+        floating_ip = network.get(self.NETWORK_FLOATING_IP)
 
         if net_id is None and port is None and subnet is None:
             msg = _('One of the properties "%(id)s", "%(port_id)s" '
@@ -47,17 +47,29 @@ class ServerNetworkMixin(object):
                                server=self.name)
             raise exception.StackValidationFailed(message=msg)
 
-        if port and not self.is_using_neutron():
+        if port is not None and not self.is_using_neutron():
             msg = _('Property "%s" is supported only for '
                     'Neutron.') % self.NETWORK_PORT
             raise exception.StackValidationFailed(message=msg)
 
         # Nova doesn't allow specify ip and port at the same time
-        if fixed_ip and port:
+        if fixed_ip and port is not None:
             raise exception.ResourcePropertyConflict(
                 "/".join([self.NETWORKS, self.NETWORK_FIXED_IP]),
                 "/".join([self.NETWORKS, self.NETWORK_PORT]))
 
+        # if user only specifies network and floating ip, floating ip
+        # can't be associated as the the neutron port isn't created/managed
+        # by heat
+        if floating_ip is not None and self.is_using_neutron():
+            if net_id is not None and port is None and subnet is None:
+                msg = _('Property "%(fip)s" is not supported if only '
+                        '"%(net)s" is specified, because the corresponding '
+                        'port can not be retrieved.'
+                        ) % dict(fip=self.NETWORK_FLOATING_IP,
+                                 net=self.NETWORK_ID)
+                raise exception.StackValidationFailed(message=msg)
+
     def _validate_belonging_subnet_to_net(self, network):
         if network.get(self.NETWORK_PORT) is None and self.is_using_neutron():
             net = self._get_network_id(network)
@@ -400,6 +412,46 @@ class ServerNetworkMixin(object):
         elif not self.is_using_neutron():
             self._floating_ip_nova_associate(floating_ip)
 
+    @staticmethod
+    def get_all_ports(server):
+        return itertools.chain(
+            server._data_get_ports(),
+            server._data_get_ports('external_ports')
+        )
+
+    def detach_ports(self, server):
+        existing_server_id = server.resource_id
+        for port in self.get_all_ports(server):
+            self.client_plugin().interface_detach(
+                existing_server_id, port['id'])
+            try:
+                if self.client_plugin().check_interface_detach(
+                        existing_server_id, port['id']):
+                    LOG.info(_LI('Detach interface %(port)s successful from '
+                                 'server %(server)s.')
+                             % {'port': port['id'],
+                                'server': existing_server_id})
+            except retrying.RetryError:
+                raise exception.InterfaceDetachFailed(
+                    port=port['id'], server=existing_server_id)
+
+    def attach_ports(self, server):
+        prev_server_id = server.resource_id
+
+        for port in self.get_all_ports(server):
+            self.client_plugin().interface_attach(prev_server_id,
+                                                  port['id'])
+            try:
+                if self.client_plugin().check_interface_attach(
+                        prev_server_id, port['id']):
+                    LOG.info(_LI('Attach interface %(port)s successful to '
+                                 'server %(server)s')
+                             % {'port': port['id'],
+                                'server': prev_server_id})
+            except retrying.RetryError:
+                raise exception.InterfaceAttachFailed(
+                    port=port['id'], server=prev_server_id)
+
     def prepare_ports_for_replace(self):
         if not self.is_using_neutron():
             return
@@ -413,21 +465,7 @@ class ServerNetworkMixin(object):
         for port_type, port in port_data:
             data[port_type].append({'id': port['id']})
 
-        # detach the ports from the server
-        server_id = self.resource_id
-        for port_type, port in port_data:
-            self.client_plugin().interface_detach(server_id, port['id'])
-            try:
-                if self.client_plugin().check_interface_detach(
-                        server_id, port['id']):
-                    LOG.info(_LI('Detach interface %(port)s successful '
-                                 'from server %(server)s when prepare '
-                                 'for replace.')
-                             % {'port': port['id'],
-                                'server': server_id})
-            except retrying.RetryError:
-                raise exception.InterfaceDetachFailed(
-                    port=port['id'], server=server_id)
+        self.detach_ports(self)
 
     def restore_ports_after_rollback(self, convergence):
         if not self.is_using_neutron():
@@ -447,46 +485,23 @@ class ServerNetworkMixin(object):
         else:
             existing_server = self
 
-        port_data = itertools.chain(
-            existing_server._data_get_ports(),
-            existing_server._data_get_ports('external_ports')
-        )
-
-        existing_server_id = existing_server.resource_id
-        for port in port_data:
-            # detach the ports from current resource
-            self.client_plugin().interface_detach(
-                existing_server_id, port['id'])
+        # Wait until server will move to active state. We can't
+        # detach interfaces from server in BUILDING state.
+        # In case of convergence, the replacement resource may be
+        # created but never have been worked on because the rollback was
+        # trigerred or new update was trigerred.
+        if existing_server.resource_id is not None:
             try:
-                if self.client_plugin().check_interface_detach(
-                        existing_server_id, port['id']):
-                    LOG.info(_LI('Detach interface %(port)s successful from '
-                                 'server %(server)s when restore after '
-                                 'rollback.')
-                             % {'port': port['id'],
-                                'server': existing_server_id})
-            except retrying.RetryError:
-                raise exception.InterfaceDetachFailed(
-                    port=port['id'], server=existing_server_id)
+                while True:
+                    active = self.client_plugin()._check_active(
+                        existing_server.resource_id)
+                    if active:
+                        break
+                    eventlet.sleep(1)
+            except exception.ResourceInError:
+                pass
 
-        # attach the ports for old resource
-        prev_port_data = itertools.chain(
-            prev_server._data_get_ports(),
-            prev_server._data_get_ports('external_ports'))
+            self.store_external_ports()
+            self.detach_ports(existing_server)
 
-        prev_server_id = prev_server.resource_id
-
-        for port in prev_port_data:
-            self.client_plugin().interface_attach(prev_server_id,
-                                                  port['id'])
-            try:
-                if self.client_plugin().check_interface_attach(
-                        prev_server_id, port['id']):
-                    LOG.info(_LI('Attach interface %(port)s successful to '
-                                 'server %(server)s when restore after '
-                                 'rollback.')
-                             % {'port': port['id'],
-                                'server': prev_server_id})
-            except retrying.RetryError:
-                raise exception.InterfaceAttachFailed(
-                    port=port['id'], server=prev_server_id)
+        self.attach_ports(prev_server)
