@@ -193,9 +193,9 @@ class OSDBInstance(resource.Resource):
                         required=True,
                         constraints=[
                             constraints.Length(max=64),
-                            constraints.AllowedPattern(r'[a-zA-Z0-9_]+'
-                                                       r'[a-zA-Z0-9_@?#\s]*'
-                                                       r'[a-zA-Z0-9_]+'),
+                            constraints.AllowedPattern(r'[a-zA-Z0-9_\-]+'
+                                                       r'[a-zA-Z0-9_@?#\s\-]*'
+                                                       r'[a-zA-Z0-9_\-]+'),
                         ]
                     ),
                 },
@@ -500,7 +500,7 @@ class OSDBInstance(resource.Resource):
                         LOG.warning(_LW("Unexpected instance state change "
                                         "during update. Retrying."))
                         return False
-                raise exc
+                raise
         return True
 
     def _update_name(self, instance, name):
