@@ -12,6 +12,7 @@
 #    under the License.
 
 import json
+import warnings
 
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -21,7 +22,7 @@ import six
 
 from heat.common import exception
 from heat.common.i18n import _
-from heat.common.i18n import _LE
+from heat.common.i18n import _LI
 from heat.common.i18n import _LW
 from heat.common import identifier
 from heat.common import template_format
@@ -31,6 +32,7 @@ from heat.engine import resource
 from heat.engine import scheduler
 from heat.engine import stack as parser
 from heat.engine import template
+from heat.objects import raw_template
 from heat.objects import stack as stack_object
 from heat.objects import stack_lock
 from heat.rpc import api as rpc_api
@@ -95,41 +97,31 @@ class StackResource(resource.Resource):
 
         # FIXME (ricolin): seems currently can not call super here
         if self.nested() is None and self.status == self.FAILED:
-            raise exception.UpdateReplace(self)
+            raise resource.UpdateReplace(self)
 
         # If stack resource is in CHECK_FAILED state, raise UpdateReplace
         # to replace the failed stack.
         if self.state == (self.CHECK, self.FAILED):
-            raise exception.UpdateReplace(self)
+            raise resource.UpdateReplace(self)
 
         if (check_init_complete and
                 self.nested() is None and
                 self.action == self.INIT and self.status == self.COMPLETE):
-            raise exception.UpdateReplace(self)
+            raise resource.UpdateReplace(self)
 
         return True
 
-    @scheduler.wrappertask
-    def update(self, after, before=None, prev_resource=None):
-        try:
-            yield super(StackResource, self).update(after, before,
-                                                    prev_resource)
-        except StopIteration:
-            with excutils.save_and_reraise_exception():
-                stack_identity = identifier.HeatIdentifier(
-                    self.context.tenant_id,
-                    self.physical_resource_name(),
-                    self.resource_id)
-                self.rpc_client().stack_cancel_update(
-                    self.context,
-                    dict(stack_identity),
-                    cancel_with_rollback=False)
+    def nested_identifier(self):
+        if self.resource_id is None:
+            return None
+        return identifier.HeatIdentifier(
+            self.context.tenant_id,
+            self.physical_resource_name(),
+            self.resource_id)
 
     def has_nested(self):
-        if self.nested() is not None:
-            return True
-
-        return False
+        """Return True if the resource has an existing nested stack."""
+        return self.resource_id is not None or self._nested is not None
 
     def nested(self):
         """Return a Stack object representing the nested (child) stack.
@@ -264,7 +256,7 @@ class StackResource(resource.Resource):
             timeout_mins = self.stack.timeout_mins
         stack_user_project_id = self.stack.stack_user_project_id
 
-        kwargs = self._stack_kwargs(user_params, child_template)
+        kwargs = self._stack_kwargs(user_params, child_template, adopt_data)
 
         adopt_data_str = None
         if adopt_data is not None:
@@ -290,14 +282,19 @@ class StackResource(resource.Resource):
             'nested_depth': self._child_nested_depth(),
             'parent_resource_name': self.name
         })
-        try:
-            result = self.rpc_client()._create_stack(self.context, **kwargs)
-        except Exception as ex:
-            self.raise_local_exception(ex)
+        with self.translate_remote_exceptions:
+            result = None
+            try:
+                result = self.rpc_client()._create_stack(self.context,
+                                                         **kwargs)
+            finally:
+                if adopt_data is None and not result:
+                    raw_template.RawTemplate.delete(self.context,
+                                                    kwargs['template_id'])
 
         self.resource_id_set(result['stack_id'])
 
-    def _stack_kwargs(self, user_params, child_template):
+    def _stack_kwargs(self, user_params, child_template, adopt_data=None):
 
         if user_params is None:
             user_params = self.child_params()
@@ -311,23 +308,39 @@ class StackResource(resource.Resource):
 
         parsed_template = self._child_parsed_template(child_template,
                                                       child_env)
-        return {
-            'template': parsed_template.t,
-            'params': child_env.user_env_as_dict(),
-            'files': parsed_template.files
-        }
+        if adopt_data is None:
+            template_id = parsed_template.store(self.context)
+            return {
+                'template_id': template_id,
+                'template': None,
+                'params': None,
+                'files': None,
+            }
+        else:
+            return {
+                'template': parsed_template.t,
+                'params': child_env.user_env_as_dict(),
+                'files': parsed_template.files,
+            }
 
     def raise_local_exception(self, ex):
+        warnings.warn('raise_local_exception() is deprecated. Use the '
+                      'translate_remote_exceptions context manager instead.',
+                      DeprecationWarning)
+        return self.translate_remote_exceptions(ex)
+
+    @excutils.exception_filter
+    def translate_remote_exceptions(self, ex):
         if (isinstance(ex, exception.ActionInProgress) and
                 self.stack.action == self.stack.ROLLBACK):
             # The update was interrupted and the rollback is already in
             # progress, so just ignore the error and wait for the rollback to
             # finish
-            return
+            return True
 
         class_name = reflection.get_class_name(ex, fully_qualified=False)
         if not class_name.endswith('_Remote'):
-            raise ex
+            return False
 
         full_message = six.text_type(ex)
         if full_message.find('\n') > -1:
@@ -380,7 +393,8 @@ class StackResource(resource.Resource):
         if status == self.IN_PROGRESS:
             return False
         elif status == self.COMPLETE:
-            ret = stack_lock.StackLock.get_engine_id(self.resource_id) is None
+            ret = stack_lock.StackLock.get_engine_id(
+                self.context, self.resource_id) is None
             if ret:
                 # Reset nested, to indicate we changed status
                 self._nested = None
@@ -397,12 +411,44 @@ class StackResource(resource.Resource):
     def check_adopt_complete(self, cookie=None):
         return self._check_status_complete(self.ADOPT)
 
+    def _try_rollback(self):
+        stack_identity = self.nested_identifier()
+        if stack_identity is None:
+            return False
+
+        try:
+            self.rpc_client().stack_cancel_update(
+                self.context,
+                dict(stack_identity),
+                cancel_with_rollback=True)
+        except exception.NotSupported:
+            return False
+
+        try:
+            data = stack_object.Stack.get_status(self.context,
+                                                 self.resource_id)
+        except exception.NotFound:
+            return False
+
+        action, status, status_reason, updated_time = data
+
+        # If nested stack is still in progress, it should eventually roll
+        # itself back due to stack_cancel_update(), so we just need to wait
+        # for that to complete
+        return status == self.stack.IN_PROGRESS
+
     def update_with_template(self, child_template, user_params=None,
                              timeout_mins=None):
         """Update the nested stack with the new template."""
         if self.id is None:
             self._store()
 
+        if self.stack.action == self.stack.ROLLBACK:
+            if self._try_rollback():
+                LOG.info(_LI('Triggered nested stack %s rollback'),
+                         self.physical_resource_name())
+                return {'target_action': self.stack.ROLLBACK}
+
         nested_stack = self.nested()
         if nested_stack is None:
             # if the create failed for some reason and the nested
@@ -431,17 +477,41 @@ class StackResource(resource.Resource):
             'stack_identity': dict(nested_stack.identifier()),
             'args': {rpc_api.PARAM_TIMEOUT: timeout_mins}
         })
-        try:
-            self.rpc_client().update_stack(self.context, **kwargs)
-        except Exception as ex:
-            LOG.exception(_LE('update_stack'))
-            self.raise_local_exception(ex)
+        with self.translate_remote_exceptions:
+            result = None
+            try:
+                result = self.rpc_client()._update_stack(self.context,
+                                                         **kwargs)
+            finally:
+                if not result:
+                    raw_template.RawTemplate.delete(self.context,
+                                                    kwargs['template_id'])
         return cookie
 
     def check_update_complete(self, cookie=None):
-        return self._check_status_complete(self.UPDATE,
+        if cookie is not None and 'target_action' in cookie:
+            target_action = cookie['target_action']
+            cookie = None
+        else:
+            target_action = self.stack.UPDATE
+        return self._check_status_complete(target_action,
                                            cookie=cookie)
 
+    def handle_update_cancel(self, cookie):
+        stack_identity = self.nested_identifier()
+        if stack_identity is not None:
+            try:
+                self.rpc_client().stack_cancel_update(
+                    self.context,
+                    dict(stack_identity),
+                    cancel_with_rollback=False)
+            except exception.NotSupported:
+                LOG.debug('Nested stack %s not in cancellable state',
+                          stack_identity.stack_name)
+
+    def handle_create_cancel(self, cookie):
+        return self.handle_update_cancel(cookie)
+
     def delete_nested(self):
         """Delete the nested stack."""
         stack = self.nested()
@@ -470,10 +540,7 @@ class StackResource(resource.Resource):
         if stack is None:
             raise exception.Error(_('Cannot suspend %s, stack not created')
                                   % self.name)
-        stack_identity = identifier.HeatIdentifier(
-            self.context.tenant_id,
-            self.physical_resource_name(),
-            self.resource_id)
+        stack_identity = self.nested_identifier()
         self.rpc_client().stack_suspend(self.context, dict(stack_identity))
 
     def check_suspend_complete(self, cookie=None):
@@ -484,10 +551,7 @@ class StackResource(resource.Resource):
         if stack is None:
             raise exception.Error(_('Cannot resume %s, stack not created')
                                   % self.name)
-        stack_identity = identifier.HeatIdentifier(
-            self.context.tenant_id,
-            self.physical_resource_name(),
-            self.resource_id)
+        stack_identity = self.nested_identifier()
         self.rpc_client().stack_resume(self.context, dict(stack_identity))
 
     def check_resume_complete(self, cookie=None):
@@ -499,10 +563,7 @@ class StackResource(resource.Resource):
             raise exception.Error(_('Cannot check %s, stack not created')
                                   % self.name)
 
-        stack_identity = identifier.HeatIdentifier(
-            self.context.tenant_id,
-            self.physical_resource_name(),
-            self.resource_id)
+        stack_identity = self.nested_identifier()
         self.rpc_client().stack_check(self.context, dict(stack_identity))
 
     def check_check_complete(self, cookie=None):
@@ -525,14 +586,12 @@ class StackResource(resource.Resource):
         stack = self.nested()
         if stack is None:
             return None
-        if op not in stack.outputs:
+
+        try:
+            return stack.outputs[op].get_value()
+        except (KeyError, Exception):
             raise exception.InvalidTemplateAttribute(resource=self.name,
                                                      key=op)
-        result = stack.output(op)
-        if result is None and stack.outputs[op].get('error_msg') is not None:
-            raise exception.InvalidTemplateAttribute(resource=self.name,
-                                                     key=op)
-        return result
 
     def _resolve_attribute(self, name):
         return self.get_output(name)
