@@ -19,6 +19,7 @@ import six
 
 from heat.common import exception
 from heat.common import template_format
+from heat.engine import resource
 from heat.engine import scheduler
 from heat.tests.autoscaling import inline_templates
 from heat.tests import common
@@ -74,31 +75,51 @@ class TestAutoScalingPolicy(common.HeatTestCase):
         self.assertIn('Alarm my-policy could '
                       'not find scaling group', six.text_type(ex))
 
-    def test_scaling_policy_not_alarm_state(self):
-        """If the details don't have 'alarm' then don't progress."""
+    def test_scaling_policy_adjust_no_action(self):
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'my-policy')
+        up_policy = self.create_scaling_policy(t, stack,
+                                               'my-policy')
+        group = stack['my-group']
+        self.patchobject(group, 'adjust',
+                         side_effect=resource.NoActionRequired())
+        mock_fin_scaling = self.patchobject(up_policy, '_finished_scaling')
+        with mock.patch.object(up_policy, '_is_scaling_allowed',
+                               return_value=True) as mock_isa:
+            self.assertRaises(resource.NoActionRequired,
+                              up_policy.handle_signal)
+            mock_isa.assert_called_once_with()
+            mock_fin_scaling.assert_called_once_with('change_in_capacity : 1',
+                                                     size_changed=False)
 
-        test = {'current': 'not_an_alarm'}
-        with mock.patch.object(pol, '_is_scaling_allowed',
-                               side_effect=AssertionError()) as dont_call:
-            self.assertRaises(exception.NoActionRequired,
-                              pol.handle_signal, details=test)
-            self.assertEqual([], dont_call.call_args_list)
+    def test_scaling_policy_adjust_size_changed(self):
+        t = template_format.parse(as_template)
+        stack = utils.parse_stack(t, params=as_params)
+        up_policy = self.create_scaling_policy(t, stack,
+                                               'my-policy')
+        group = stack['my-group']
+        self.patchobject(group, 'adjust')
+        mock_fin_scaling = self.patchobject(up_policy, '_finished_scaling')
+        with mock.patch.object(up_policy, '_is_scaling_allowed',
+                               return_value=True) as mock_isa:
+            self.assertIsNone(up_policy.handle_signal())
+            mock_isa.assert_called_once_with()
+            mock_fin_scaling.assert_called_once_with('change_in_capacity : 1',
+                                                     size_changed=True)
 
     def test_scaling_policy_cooldown_toosoon(self):
         """If _is_scaling_allowed() returns False don't progress."""
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
         pol = self.create_scaling_policy(t, stack, 'my-policy')
+        group = stack['my-group']
         test = {'current': 'alarm'}
 
-        with mock.patch.object(pol.stack, 'resource_by_refid',
+        with mock.patch.object(group, 'adjust',
                                side_effect=AssertionError) as dont_call:
             with mock.patch.object(pol, '_is_scaling_allowed',
                                    return_value=False) as mock_cip:
-                self.assertRaises(exception.NoActionRequired,
+                self.assertRaises(resource.NoActionRequired,
                                   pol.handle_signal, details=test)
                 mock_cip.assert_called_once_with()
             self.assertEqual([], dont_call.call_args_list)
@@ -236,7 +257,7 @@ class TestCooldownMixin(common.HeatTestCase):
         reason = 'cool as'
         meta_set = self.patchobject(pol, 'metadata_set')
         self.patchobject(timeutils, 'utcnow', return_value=nowish)
-        pol._finished_scaling(reason)
+        pol._finished_scaling(reason, size_changed=True)
         meta_set.assert_called_once_with(
             {'cooldown': {nowish.isoformat(): reason},
              'scaling_in_progress': False})
