@@ -20,7 +20,7 @@ from heat.common import exception
 from heat.common import grouputils
 from heat.common import template_format
 from heat.engine.clients.os import nova
-from heat.engine import function
+from heat.engine import resource
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
 from heat.tests.autoscaling import inline_templates
@@ -301,43 +301,40 @@ class TestGroupAdjust(common.HeatTestCase):
 
     def test_scaling_policy_cooldown_toosoon(self):
         """If _is_scaling_allowed() returns False don't progress."""
-        dont_call = self.patchobject(grouputils, 'get_size')
+        dont_call = self.patchobject(self.group, 'resize')
         self.patchobject(self.group, '_is_scaling_allowed',
                          return_value=False)
-        self.assertRaises(exception.NoActionRequired,
+        self.assertRaises(resource.NoActionRequired,
                           self.group.adjust, 1)
         self.assertEqual([], dont_call.call_args_list)
 
     def test_scaling_same_capacity(self):
-        """Alway resize even if the capacity is the same."""
+        """Don't resize when capacity is the same."""
         self.patchobject(grouputils, 'get_size', return_value=3)
         resize = self.patchobject(self.group, 'resize')
         finished_scaling = self.patchobject(self.group, '_finished_scaling')
         notify = self.patch('heat.engine.notification.autoscaling.send')
-        self.patchobject(self.group, '_is_scaling_allowed',
-                         return_value=True)
-        self.group.adjust(3, adjustment_type='ExactCapacity')
-
-        expected_notifies = [
-            mock.call(
-                capacity=3, suffix='start',
-                adjustment_type='ExactCapacity',
-                groupname=u'WebServerGroup',
-                message=u'Start resizing the group WebServerGroup',
-                adjustment=3,
-                stack=self.group.stack),
-            mock.call(
-                capacity=3, suffix='end',
-                adjustment_type='ExactCapacity',
-                groupname=u'WebServerGroup',
-                message=u'End resizing the group WebServerGroup',
-                adjustment=3,
-                stack=self.group.stack)]
-
+        self.assertRaises(resource.NoActionRequired,
+                          self.group.adjust, 3,
+                          adjustment_type='ExactCapacity')
+        expected_notifies = []
         self.assertEqual(expected_notifies, notify.call_args_list)
-        resize.assert_called_once_with(3)
-        finished_scaling.assert_called_once_with('ExactCapacity : 3',
-                                                 changed_size=False)
+        self.assertEqual(0, resize.call_count)
+        self.assertEqual(0, finished_scaling.call_count)
+
+    def test_scaling_update_in_progress(self):
+        """Don't resize when update in progress"""
+        self.group.state_set('UPDATE', 'IN_PROGRESS')
+        resize = self.patchobject(self.group, 'resize')
+        finished_scaling = self.patchobject(self.group, '_finished_scaling')
+        notify = self.patch('heat.engine.notification.autoscaling.send')
+        self.assertRaises(resource.NoActionRequired,
+                          self.group.adjust, 3,
+                          adjustment_type='ExactCapacity')
+        expected_notifies = []
+        self.assertEqual(expected_notifies, notify.call_args_list)
+        self.assertEqual(0, resize.call_count)
+        self.assertEqual(0, finished_scaling.call_count)
 
     def test_scale_up_min_adjustment(self):
         self.patchobject(grouputils, 'get_size', return_value=1)
@@ -368,7 +365,8 @@ class TestGroupAdjust(common.HeatTestCase):
         self.assertEqual(expected_notifies, notify.call_args_list)
         resize.assert_called_once_with(3)
         finished_scaling.assert_called_once_with(
-            'PercentChangeInCapacity : 33', changed_size=True)
+            'PercentChangeInCapacity : 33',
+            size_changed=True)
 
     def test_scale_down_min_adjustment(self):
         self.patchobject(grouputils, 'get_size', return_value=5)
@@ -399,7 +397,8 @@ class TestGroupAdjust(common.HeatTestCase):
         self.assertEqual(expected_notifies, notify.call_args_list)
         resize.assert_called_once_with(3)
         finished_scaling.assert_called_once_with(
-            'PercentChangeInCapacity : -33', changed_size=True)
+            'PercentChangeInCapacity : -33',
+            size_changed=True)
 
     def test_scaling_policy_cooldown_ok(self):
         self.patchobject(grouputils, 'get_size', return_value=0)
@@ -428,7 +427,7 @@ class TestGroupAdjust(common.HeatTestCase):
         self.assertEqual(expected_notifies, notify.call_args_list)
         resize.assert_called_once_with(1)
         finished_scaling.assert_called_once_with('ChangeInCapacity : 1',
-                                                 changed_size=True)
+                                                 size_changed=True)
         grouputils.get_size.assert_called_once_with(self.group)
 
     def test_scaling_policy_resize_fail(self):
@@ -690,7 +689,7 @@ class RollingUpdatePolicyDiffTest(common.HeatTestCase):
 
         # get the json snippet for the current InstanceGroup resource
         current_grp = current_stack['WebServerGroup']
-        current_snippets = dict((n, r.parsed_template())
+        current_snippets = dict((n, r.frozen_definition())
                                 for n, r in current_stack.items())
         current_grp_json = current_snippets[current_grp.name]
 
@@ -702,29 +701,19 @@ class RollingUpdatePolicyDiffTest(common.HeatTestCase):
         # get the updated json snippet for the InstanceGroup resource in the
         # context of the current stack
         updated_grp = updated_stack['WebServerGroup']
-        updated_grp_json = function.resolve(updated_grp.t)
+        updated_grp_json = updated_grp.t.freeze()
 
         # identify the template difference
         tmpl_diff = updated_grp.update_template_diff(
             updated_grp_json, current_grp_json)
-        updated_policy = (updated_grp.t['UpdatePolicy']
-                          if 'UpdatePolicy' in updated_grp.t else None)
-        expected = {u'UpdatePolicy': updated_policy}
-        self.assertEqual(expected, tmpl_diff)
+        self.assertTrue(tmpl_diff.update_policy_changed())
 
         # test application of the new update policy in handle_update
-        update_snippet = rsrc_defn.ResourceDefinition(
-            current_grp.name,
-            current_grp.type(),
-            properties=updated_grp.t['Properties'],
-            update_policy=updated_policy)
         current_grp._try_rolling_update = mock.MagicMock()
         current_grp.resize = mock.MagicMock()
-        current_grp.handle_update(update_snippet, tmpl_diff, None)
-        if updated_policy is None:
-            self.assertEqual({}, current_grp.update_policy.data)
-        else:
-            self.assertEqual(updated_policy, current_grp.update_policy.data)
+        current_grp.handle_update(updated_grp_json, tmpl_diff, None)
+        self.assertEqual(updated_grp_json._update_policy or {},
+                         current_grp.update_policy.data)
 
     def test_update_policy_added(self):
         self.validate_update_policy_diff(inline_templates.as_template,
