@@ -15,6 +15,7 @@ import mock
 import six
 
 from heat.common import exception
+from heat.engine.clients.os import cinder as c_plugin
 from heat.engine import stack
 from heat.engine import template
 from heat.tests import common
@@ -39,6 +40,8 @@ class CinderVolumeTypeTest(common.HeatTestCase):
         super(CinderVolumeTypeTest, self).setUp()
 
         self.ctx = utils.dummy_context()
+        self.patchobject(c_plugin.CinderClientPlugin, 'has_extension',
+                         return_value=True)
         self.stack = stack.Stack(
             self.ctx, 'cinder_volume_type_test_stack',
             template.Template(volume_type_template)
@@ -61,12 +64,16 @@ class CinderVolumeTypeTest(common.HeatTestCase):
         volume_type_id = '927202df-1afb-497f-8368-9c2d2f26e5db'
         value.id = volume_type_id
         self.volume_types.create.return_value = value
-        self.my_volume_type.t['Properties']['is_public'] = is_public
+        tmpl = self.stack.t.t
+        props = tmpl['resources']['my_volume_type']['properties'].copy()
+        props['is_public'] = is_public
         if projects:
-            self.my_volume_type.t['Properties']['projects'] = projects
+            props['projects'] = projects
             project = collections.namedtuple('Project', ['id'])
             stub_projects = [project(p) for p in projects]
             self.project_list.side_effect = [p for p in stub_projects]
+        self.my_volume_type.t = self.my_volume_type.t.freeze(properties=props)
+        self.my_volume_type.reparse()
         self.my_volume_type.handle_create()
         self.volume_types.create.assert_called_once_with(
             name='volumeBackend', is_public=is_public, description=None)
@@ -165,19 +172,13 @@ class CinderVolumeTypeTest(common.HeatTestCase):
         self.volume_type_access.add_project_access.assert_called_once_with(
             self.my_volume_type.resource_id, 'id3')
 
-    def test_validate_projects_in_v1(self):
-        self.my_volume_type.t['Properties']['is_public'] = False
-        self.my_volume_type.t['Properties']['projects'] = ['id1']
-        self.cinderclient.volume_api_version = 1
-        self.stub_KeystoneProjectConstraint()
-        ex = self.assertRaises(exception.NotSupported,
-                               self.my_volume_type.validate)
-        expected = 'Using Cinder API V1, volume type access is not supported.'
-        self.assertEqual(expected, six.text_type(ex))
-
     def test_validate_projects_when_public(self):
-        self.my_volume_type.t['Properties']['projects'] = ['id1']
-        self.my_volume_type.t['Properties']['is_public'] = True
+        tmpl = self.stack.t.t
+        props = tmpl['resources']['my_volume_type']['properties'].copy()
+        props['is_public'] = True
+        props['projects'] = ['id1']
+        self.my_volume_type.t = self.my_volume_type.t.freeze(properties=props)
+        self.my_volume_type.reparse()
         self.cinderclient.volume_api_version = 2
         self.stub_KeystoneProjectConstraint()
         ex = self.assertRaises(exception.StackValidationFailed,
@@ -187,17 +188,73 @@ class CinderVolumeTypeTest(common.HeatTestCase):
         self.assertEqual(expected, six.text_type(ex))
 
     def test_validate_projects_when_private(self):
-        self.my_volume_type.t['Properties']['projects'] = ['id1']
-        self.my_volume_type.t['Properties']['is_public'] = False
+        tmpl = self.stack.t.t
+        props = tmpl['resources']['my_volume_type']['properties'].copy()
+        props['is_public'] = False
+        props['projects'] = ['id1']
+        self.my_volume_type.t = self.my_volume_type.t.freeze(properties=props)
+        self.my_volume_type.reparse()
         self.cinderclient.volume_api_version = 2
         self.stub_KeystoneProjectConstraint()
         self.assertIsNone(self.my_volume_type.validate())
 
-    def test_volume_type_show_resource(self):
-        volume_type_id = '927202df-1afb-497f-8368-9c2d2f26e5db'
-        self.my_volume_type.resource_id = volume_type_id
+    def test_volume_type_get_live_state_public(self):
+        self.my_volume_type.resource_id = '1234'
         volume_type = mock.Mock()
-        volume_type._info = {'vtype': 'info'}
+        volume_type.to_dict.return_value = {'name': 'test',
+                                            'is_public': True,
+                                            'description': 'test1',
+                                            'metadata': {'one': 'two'}}
         self.volume_types.get.return_value = volume_type
-        self.assertEqual({'vtype': 'info'},
-                         self.my_volume_type.FnGetAtt('show'))
+        volume_type.get_keys.return_value = {'one': 'two'}
+
+        volume_type_access = mock.MagicMock()
+        self.cinderclient.volume_type_access = volume_type_access
+
+        reality = self.my_volume_type.get_live_state(
+            self.my_volume_type.properties)
+        expected = {
+            'name': 'test',
+            'is_public': True,
+            'description': 'test1',
+            'projects': [],
+            'metadata': {'one': 'two'}
+        }
+        self.assertEqual(set(expected.keys()), set(reality.keys()))
+        for key in reality:
+            self.assertEqual(expected[key], reality[key])
+        self.assertEqual(0, volume_type_access.list.call_count)
+
+    def test_volume_type_get_live_state_not_public(self):
+        self.my_volume_type.resource_id = '1234'
+        volume_type = mock.Mock()
+        volume_type.to_dict.return_value = {'name': 'test',
+                                            'is_public': False,
+                                            'description': 'test1',
+                                            'metadata': {'one': 'two'}}
+        self.volume_types.get.return_value = volume_type
+        volume_type.get_keys.return_value = {'one': 'two'}
+        volume_type_access = mock.MagicMock()
+
+        class Access(object):
+            def __init__(self, idx, project, info):
+                self.volumetype_id = idx
+                self.project_id = project
+                self._info = info
+
+        volume_type_access.list.return_value = [
+            Access('1234', '1', {'volumetype_id': '1234', 'project_id': '1'}),
+            Access('1234', '2', {'volumetype_id': '1234', 'project_id': '2'})]
+        self.cinderclient.volume_type_access = volume_type_access
+
+        reality = self.my_volume_type.get_live_state(
+            self.my_volume_type.properties)
+        expected = {
+            'name': 'test',
+            'is_public': False,
+            'description': 'test1',
+            'metadata': {'one': 'two'},
+            'projects': ['1', '2']
+        }
+        self.assertEqual(expected, reality)
+        volume_type_access.list.assert_called_once_with('1234')
