@@ -12,7 +12,6 @@
 #    under the License.
 
 import collections
-import copy
 
 from heatclient import exc
 from heatclient.v1 import stacks
@@ -25,6 +24,7 @@ from heat.common.i18n import _
 from heat.common import template_format
 from heat.engine.clients.os import heat_plugin
 from heat.engine import environment
+from heat.engine import resource
 from heat.engine.resources.openstack.heat import remote_stack
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
@@ -130,7 +130,7 @@ class RemoteStackTest(tests_common.HeatTestCase):
         self.that_region = 'RegionTwo'
         self.bad_region = 'RegionNone'
 
-        cfg.CONF.set_override('action_retry_limit', 0)
+        cfg.CONF.set_override('action_retry_limit', 0, enforce_type=True)
         self.parent = None
         self.heat = None
         self.client_plugin = None
@@ -584,7 +584,7 @@ class RemoteStackTest(tests_common.HeatTestCase):
 
         rsrc = self.create_remote_stack()
 
-        props = copy.deepcopy(rsrc.parsed_template()['Properties'])
+        props = dict(rsrc.properties)
         props['parameters']['name'] = 'bar'
         update_snippet = rsrc_defn.ResourceDefinition(rsrc.name,
                                                       rsrc.type(),
@@ -612,12 +612,12 @@ class RemoteStackTest(tests_common.HeatTestCase):
     def test_update_with_replace(self):
         rsrc = self.create_remote_stack()
 
-        props = copy.deepcopy(rsrc.parsed_template()['Properties'])
+        props = dict(rsrc.properties)
         props['context']['region_name'] = 'RegionOne'
         update_snippet = rsrc_defn.ResourceDefinition(rsrc.name,
                                                       rsrc.type(),
                                                       props)
-        self.assertRaises(exception.UpdateReplace,
+        self.assertRaises(resource.UpdateReplace,
                           scheduler.TaskRunner(rsrc.update, update_snippet))
 
     def test_update_failed(self):
@@ -627,7 +627,7 @@ class RemoteStackTest(tests_common.HeatTestCase):
 
         rsrc = self.create_remote_stack()
 
-        props = copy.deepcopy(rsrc.parsed_template()['Properties'])
+        props = dict(rsrc.properties)
         props['parameters']['name'] = 'bar'
         update_snippet = rsrc_defn.ResourceDefinition(rsrc.name,
                                                       rsrc.type(),
@@ -650,7 +650,7 @@ class RemoteStackTest(tests_common.HeatTestCase):
 
         rsrc = self.create_remote_stack()
 
-        props = copy.deepcopy(rsrc.parsed_template()['Properties'])
+        props = dict(rsrc.properties)
         update_snippet = rsrc_defn.ResourceDefinition(rsrc.name,
                                                       rsrc.type(),
                                                       props)
@@ -683,9 +683,9 @@ class RemoteStackTest(tests_common.HeatTestCase):
         rsrc = self.create_remote_stack()
         rsrc.state_set(rsrc.CHECK, rsrc.FAILED)
 
-        props = copy.deepcopy(rsrc.parsed_template()['Properties'])
+        props = dict(rsrc.properties)
         update_snippet = rsrc_defn.ResourceDefinition(rsrc.name,
                                                       rsrc.type(),
                                                       props)
-        self.assertRaises(exception.UpdateReplace,
+        self.assertRaises(resource.UpdateReplace,
                           scheduler.TaskRunner(rsrc.update, update_snippet))
