@@ -14,9 +14,10 @@
 import copy
 import mock
 
-from heat.common.exception import StackValidationFailed
+from heat.common import exception
 from heat.common import grouputils
 from heat.engine.resources.openstack.heat import resource_chain
+from heat.engine import rsrc_defn
 from heat.tests import common
 from heat.tests import utils
 
@@ -120,7 +121,7 @@ class ResourceChainTest(common.HeatTestCase):
         # No error, but no resources to create
         self.assertTrue('resources' not in tmpl)
         # Sanity check that it's actually a template
-        self.assertTrue('heat_template_version' in tmpl)
+        self.assertIn('heat_template_version', tmpl)
 
     def test_validate_nested_stack(self):
         # Test - should not raise exception
@@ -143,8 +144,8 @@ class ResourceChainTest(common.HeatTestCase):
         try:
             chain.validate_nested_stack()
             self.fail('Exception expected')
-        except StackValidationFailed as e:
-            self.assertTrue('unknown property group' in e.message.lower())
+        except exception.StackValidationFailed as e:
+            self.assertIn('unknown property group', e.message.lower())
 
     def test_validate_fake_resource_type(self):
         # Setup
@@ -159,9 +160,9 @@ class ResourceChainTest(common.HeatTestCase):
         try:
             chain.validate_nested_stack()
             self.fail('Exception expected')
-        except StackValidationFailed as e:
-            self.assertTrue('could not be found' in e.message.lower())
-            self.assertTrue('foo' in e.message)
+        except exception.StackValidationFailed as e:
+            self.assertIn('could not be found', e.message.lower())
+            self.assertIn('foo', e.message)
 
     @mock.patch.object(resource_chain.ResourceChain, 'create_with_template')
     def test_handle_create(self, mock_create):
@@ -187,7 +188,11 @@ class ResourceChainTest(common.HeatTestCase):
         chain = self._create_chain(TEMPLATE)
 
         # Test
-        chain.handle_update(None, None, None)
+        json_snippet = rsrc_defn.ResourceDefinition(
+            'test-chain', 'OS::Heat::ResourceChain',
+            TEMPLATE['resources']['test-chain']['properties'])
+
+        chain.handle_update(json_snippet, None, None)
 
         # Verify
         expected_tmpl = chain.child_template()
