@@ -16,7 +16,7 @@ import six
 
 from heat.common import exception
 from heat.common import template_format
-from heat.engine import resources
+from heat.engine import resource
 from heat.engine.resources.openstack.manila import security_service
 from heat.engine import scheduler
 from heat.engine import template
@@ -74,9 +74,6 @@ class ManilaSecurityServiceTest(common.HeatTestCase):
 
     def setUp(self):
         super(ManilaSecurityServiceTest, self).setUp()
-        resources.initialise()
-        utils.setup_dummy_db()
-        self.ctx = utils.dummy_context()
 
         t = template_format.parse(stack_template)
         self.stack = utils.parse_stack(t)
@@ -94,7 +91,7 @@ class ManilaSecurityServiceTest(common.HeatTestCase):
         self.client.security_services.get.return_value = value
         scheduler.TaskRunner(ss.create)()
         args = self.client.security_services.create.call_args[1]
-        self.assertEqual(self.rsrc_defn['Properties'], args)
+        self.assertEqual(self.rsrc_defn._properties, args)
         self.assertEqual('12345', ss.resource_id)
         return ss
 
@@ -142,7 +139,7 @@ class ManilaSecurityServiceTest(common.HeatTestCase):
         rsrc_defns = template.Template(t).resource_definitions(self.stack)
         new_ss = rsrc_defns['security_service']
         self.assertEqual(0, self.client.security_services.update.call_count)
-        err = self.assertRaises(exception.UpdateReplace,
+        err = self.assertRaises(resource.UpdateReplace,
                                 scheduler.TaskRunner(ss.update, new_ss))
         msg = 'The Resource security_service requires replacement.'
         self.assertEqual(msg, six.text_type(err))
