@@ -14,7 +14,6 @@
 import mock
 
 from heat.engine.clients.os import monasca as client_plugin
-from heat.engine import resource
 from heat.engine.resources.openstack.monasca import alarm_definition
 from heat.engine import stack
 from heat.engine import template
@@ -45,27 +44,13 @@ sample_template = {
 RESOURCE_TYPE = 'OS::Monasca::AlarmDefinition'
 
 
-class MonascaAlarmDefinition(alarm_definition.MonascaAlarmDefinition):
-    """This class overrides the is_service_available to return True.
-
-    Monasca service is not available by default. So, this class overrides
-    the is_service_available to return True.
-    """
-    @classmethod
-    def is_service_available(cls, context):
-        return True
-
-
 class MonascaAlarmDefinitionTest(common.HeatTestCase):
 
     def setUp(self):
         super(MonascaAlarmDefinitionTest, self).setUp()
 
         self.ctx = utils.dummy_context()
-        # As monascaclient is not part of requirements.txt, RESOURCE_TYPE is
-        # not registered by default. For testing, its registered here
-        resource._register_class(RESOURCE_TYPE,
-                                 MonascaAlarmDefinition)
+
         self.stack = stack.Stack(
             self.ctx, 'test_stack',
             template.Template(sample_template)
@@ -209,14 +194,6 @@ class MonascaAlarmDefinitionTest(common.HeatTestCase):
         self.assertIsNone(self.test_resource.handle_delete())
 
     def test_resource_handle_delete_not_found(self):
-        # TODO(skraynev): remove it when monasca client will be
-        #                 merged in global requirements
-        class NotFound(Exception):
-            pass
-
-        client_plugin.monasca_exc = mock.Mock()
-        client_plugin.monasca_exc.NotFound = NotFound
-
         self.test_resource.resource_id = '477e8273-60a7-4c41-b683-fdb0bc7cd151'
         mock_alarm_delete = self.test_client.alarm_definitions.delete
         mock_alarm_delete.side_effect = client_plugin.monasca_exc.NotFound
