@@ -59,9 +59,9 @@ class TestRequestContext(common.HeatTestCase):
             username=self.ctx.get('username'),
             password=self.ctx.get('password'),
             aws_creds=self.ctx.get('aws_creds'),
-            tenant=self.ctx.get('tenant'),
-            tenant_id=self.ctx.get('tenant_id'),
-            user_id=self.ctx.get('user_id'),
+            project_name=self.ctx.get('tenant'),
+            tenant=self.ctx.get('tenant_id'),
+            user=self.ctx.get('user_id'),
             auth_url=self.ctx.get('auth_url'),
             roles=self.ctx.get('roles'),
             show_deleted=self.ctx.get('show_deleted'),
@@ -69,7 +69,6 @@ class TestRequestContext(common.HeatTestCase):
             auth_token_info=self.ctx.get('auth_token_info'),
             trustor_user_id=self.ctx.get('trustor_user_id'),
             trust_id=self.ctx.get('trust_id'),
-            user=self.ctx.get('user'),
             region_name=self.ctx.get('region_name'),
             user_domain_id=self.ctx.get('user_domain'),
             project_domain_id=self.ctx.get('project_domain'))
@@ -91,6 +90,11 @@ class TestRequestContext(common.HeatTestCase):
                     k == 'user_domain_id' or
                     k == 'project_domain_id'):
                 continue
+
+            # these values are different between attribute and context
+            if k == 'tenant' or k == 'user':
+                continue
+
             self.assertEqual(self.ctx.get(k), ctx.to_dict().get(k))
             override = '%s_override' % k
             setattr(ctx, k, override)
@@ -123,7 +127,7 @@ class TestRequestContext(common.HeatTestCase):
     def test_keystone_v3_endpoint_in_context(self):
         """Ensure that the context is the preferred source for the auth_uri."""
         cfg.CONF.set_override('auth_uri', 'http://xyz',
-                              group='clients_keystone')
+                              group='clients_keystone', enforce_type=True)
         policy_check = 'heat.common.policy.Enforcer.check_is_admin'
         with mock.patch(policy_check) as pc:
             pc.return_value = False
@@ -139,14 +143,14 @@ class TestRequestContext(common.HeatTestCase):
         the preferred source when the context does not have the auth_uri.
         """
         cfg.CONF.set_override('auth_uri', 'http://xyz',
-                              group='clients_keystone')
+                              group='clients_keystone', enforce_type=True)
         importutils.import_module('keystonemiddleware.auth_token')
         cfg.CONF.set_override('auth_uri', 'http://abc/v2.0',
-                              group='keystone_authtoken')
+                              group='keystone_authtoken', enforce_type=True)
         policy_check = 'heat.common.policy.Enforcer.check_is_admin'
         with mock.patch(policy_check) as pc:
             pc.return_value = False
-            with mock.patch('keystoneclient.discover.Discover') as discover:
+            with mock.patch('keystoneauth1.discover.Discover') as discover:
                 class MockDiscover(object):
                     def url_for(self, endpoint):
                         return 'http://xyz/v3'
@@ -164,7 +168,7 @@ class TestRequestContext(common.HeatTestCase):
         """
         importutils.import_module('keystonemiddleware.auth_token')
         cfg.CONF.set_override('auth_uri', 'http://abc/v2.0',
-                              group='keystone_authtoken')
+                              group='keystone_authtoken', enforce_type=True)
         policy_check = 'heat.common.policy.Enforcer.check_is_admin'
         with mock.patch(policy_check) as pc:
             pc.return_value = False
@@ -187,18 +191,18 @@ class TestRequestContext(common.HeatTestCase):
     def test_create_trusts_auth_plugin_with_correct_user_domain_id(self):
         importutils.import_module('keystonemiddleware.auth_token')
         cfg.CONF.set_override('auth_uri', 'http://abc/v2.0',
-                              group='keystone_authtoken')
+                              group='keystone_authtoken', enforce_type=True)
         cfg.CONF.set_override('admin_user', 'heat',
-                              group='keystone_authtoken')
+                              group='keystone_authtoken', enforce_type=True)
         cfg.CONF.set_override('admin_password', 'password',
-                              group='keystone_authtoken')
+                              group='keystone_authtoken', enforce_type=True)
         policy_check = 'heat.common.policy.Enforcer.check_is_admin'
         with mock.patch(policy_check) as pc:
             pc.return_value = False
             ctx = context.RequestContext(auth_url=None,
                                          user_domain_id='non-default',
                                          username='test')
-            with mock.patch('keystoneclient.auth.identity.v3.Password') as ps:
+            with mock.patch('keystoneauth1.identity.generic.Password') as ps:
                 ctx.trusts_auth_plugin
                 ps.assert_called_once_with(username='heat',
                                            password='password',
@@ -206,6 +210,29 @@ class TestRequestContext(common.HeatTestCase):
                                            auth_url='http://abc/v3',
                                            trust_id=None)
 
+    def test_cache(self):
+        ctx = context.RequestContext.from_dict(self.ctx)
+
+        class Class1(object):
+            pass
+
+        class Class2(object):
+            pass
+
+        self.assertEqual(0, len(ctx._object_cache))
+
+        cache1 = ctx.cache(Class1)
+        self.assertIsInstance(cache1, Class1)
+        self.assertEqual(1, len(ctx._object_cache))
+
+        cache1a = ctx.cache(Class1)
+        self.assertEqual(cache1, cache1a)
+        self.assertEqual(1, len(ctx._object_cache))
+
+        cache2 = ctx.cache(Class2)
+        self.assertIsInstance(cache2, Class2)
+        self.assertEqual(2, len(ctx._object_cache))
+
 
 class RequestContextMiddlewareTest(common.HeatTestCase):
 
@@ -214,7 +241,6 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
         dict(
             environ=None,
             headers={},
-            expected_exception=None,
             context_dict={
                 'auth_token': None,
                 'auth_token_info': None,
@@ -247,7 +273,6 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
                 'X-Auth-Url': 'http://192.0.2.1:5000/v1',
                 'X-Roles': 'role1,role2,role3'
             },
-            expected_exception=None,
             context_dict={
                 'auth_token': 'atoken',
                 'auth_url': 'http://192.0.2.1:5000/v1',
@@ -277,7 +302,6 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
                 'X-Auth-Url': 'http://192.0.2.1:5000/v1',
                 'X-Roles': 'role1,role2,role3',
             },
-            expected_exception=None,
             context_dict={
                 'auth_token': 'atoken',
                 'auth_url': 'http://192.0.2.1:5000/v1',
@@ -306,7 +330,6 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
                 'X-Auth-Url': 'http://192.0.2.1:5000/v1',
                 'X-Roles': 'role1,role2,role3',
             },
-            expected_exception=None,
             context_dict={
                 'auth_token': 'atoken2',
                 'auth_token_info': {'info': 123},
@@ -324,14 +347,6 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
                 'user_id': '7a87ff18-31c6-45ce-a186-ec7987f488c3',
                 'username': None
             })
-    ), (
-        'malformed_roles',
-        dict(
-            environ=None,
-            headers={
-                'X-Roles': [],
-            },
-            expected_exception=exception.NotAuthenticated)
     )]
 
     def setUp(self):
@@ -345,15 +360,12 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
         middleware = context.ContextMiddleware(None, None)
         request = webob.Request.blank('/stacks', headers=self.headers,
                                       environ=self.environ)
-        if self.expected_exception:
-            self.assertRaises(
-                self.expected_exception, middleware.process_request, request)
-        else:
-            self.assertIsNone(middleware.process_request(request))
-            ctx = request.context.to_dict()
-            for k, v in self.context_dict.items():
-                self.assertEqual(v, ctx[k], 'Key %s values do not match' % k)
-            self.assertIsNotNone(ctx.get('request_id'))
+
+        self.assertIsNone(middleware.process_request(request))
+        ctx = request.context.to_dict()
+        for k, v in self.context_dict.items():
+            self.assertEqual(v, ctx[k], 'Key %s values do not match' % k)
+        self.assertIsNotNone(ctx.get('request_id'))
 
     def test_context_middleware_with_requestid(self):
 
@@ -362,14 +374,11 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
                                       environ=self.environ)
         req_id = 'req-5a63f0d7-1b69-447b-b621-4ea87cc7186d'
         request.environ[request_id.ENV_REQUEST_ID] = req_id
-        if self.expected_exception:
-            self.assertRaises(
-                self.expected_exception, middleware.process_request, request)
-        else:
-            self.assertIsNone(middleware.process_request(request))
-            ctx = request.context.to_dict()
-            for k, v in self.context_dict.items():
-                self.assertEqual(v, ctx[k], 'Key %s values do not match' % k)
-            self.assertEqual(
-                ctx.get('request_id'), req_id,
-                'Key request_id values do not match')
+
+        self.assertIsNone(middleware.process_request(request))
+        ctx = request.context.to_dict()
+        for k, v in self.context_dict.items():
+            self.assertEqual(v, ctx[k], 'Key %s values do not match' % k)
+        self.assertEqual(
+            ctx.get('request_id'), req_id,
+            'Key request_id values do not match')
