@@ -15,8 +15,8 @@ from oslo_serialization import jsonutils
 import six
 
 from heat.common import exception
-from heat.engine.cfn import functions as cfn_funcs
 from heat.engine import constraints
+from heat.engine.hot import functions as hot_funcs
 from heat.engine.hot import parameters as hot_param
 from heat.engine import parameters
 from heat.engine import plugin_manager
@@ -598,7 +598,7 @@ class PropertySchemaTest(common.HeatTestCase):
         self.assertEqual(properties.Schema.LIST, schema.type)
         self.assertIsNone(schema.default)
         self.assertFalse(schema.required)
-        self.assertFalse(schema.allow_conversion)
+        self.assertTrue(schema.allow_conversion)
 
         props = properties.Properties({'test': schema}, {})
         props.validate()
@@ -903,6 +903,13 @@ class PropertyTest(common.HeatTestCase):
         p = properties.Property({'Type': 'List'})
         self.assertRaises(TypeError, p.get_value, {'foo': 'bar'})
 
+    def test_list_is_delimited(self):
+        p = properties.Property({'Type': 'List'})
+        self.assertRaises(TypeError, p.get_value, 'foo,bar')
+        p.schema.allow_conversion = True
+        self.assertEqual(['foo', 'bar'], p.get_value('foo,bar'))
+        self.assertEqual(['foo'], p.get_value('foo'))
+
     def test_list_maxlength_good(self):
         schema = {'Type': 'List',
                   'MaxLength': '3'}
@@ -1228,7 +1235,7 @@ class PropertiesTest(common.HeatTestCase):
         # define properties with function and constraint
         props = properties.Properties(
             schema,
-            {'foo': cfn_funcs.ResourceRef(
+            {'foo': hot_funcs.GetResource(
                 stack, 'get_resource', 'another_res')},
             test_resolver)
 
@@ -1899,9 +1906,8 @@ class PropertiesValidationTest(common.HeatTestCase):
         self.assertEqual({}, props)
 
     def test_update_allowed_and_immutable_contradict(self):
-        schema = {'foo': properties.Schema(
-            properties.Schema.STRING,
-            update_allowed=True,
-            immutable=True)}
-        props = properties.Properties(schema, {})
-        self.assertRaises(exception.InvalidSchemaError, props.validate)
+        self.assertRaises(exception.InvalidSchemaError,
+                          properties.Schema,
+                          properties.Schema.STRING,
+                          update_allowed=True,
+                          immutable=True)
