@@ -73,8 +73,8 @@ class TestTranslationRule(common.HeatTestCase):
                                 translation.TranslationRule.ADD,
                                 'networks.network',
                                 'value')
-        self.assertEqual('source_path should be a list with path instead of '
-                         '%s.' % str, six.text_type(exc))
+        self.assertEqual('translation_path should be a list with path instead '
+                         'of %s.' % str, six.text_type(exc))
 
         exc = self.assertRaises(ValueError,
                                 translation.TranslationRule,
@@ -82,7 +82,7 @@ class TestTranslationRule(common.HeatTestCase):
                                 translation.TranslationRule.ADD,
                                 [],
                                 mock.ANY)
-        self.assertEqual('source_path must be non-empty list with path.',
+        self.assertEqual('translation_path must be non-empty list with path.',
                          six.text_type(exc))
 
         exc = self.assertRaises(ValueError,
@@ -90,9 +90,10 @@ class TestTranslationRule(common.HeatTestCase):
                                 props,
                                 translation.TranslationRule.ADD,
                                 ['any'],
-                                mock.ANY,
+                                'value',
                                 'value_name')
-        self.assertEqual('Use value_name only for replacing list elements.',
+        self.assertEqual('Either value or value_name should be specified for '
+                         'rule Add.',
                          six.text_type(exc))
 
         exc = self.assertRaises(ValueError,
@@ -359,8 +360,10 @@ class TestTranslationRule(common.HeatTestCase):
             translation.TranslationRule.REPLACE,
             ['bar'],
             value_path=['far'])
-        ex = self.assertRaises(ValueError, rule.execute_rule)
-        self.assertEqual('Cannot use bar and far at the same time.',
+        ex = self.assertRaises(exception.ResourcePropertyConflict,
+                               rule.execute_rule)
+        self.assertEqual("Cannot define the following properties at the "
+                         "same time: ['bar', 'far'].",
                          six.text_type(ex))
 
     def test_replace_rule_str_value_path(self):
@@ -527,7 +530,7 @@ class TestTranslationRule(common.HeatTestCase):
             pass
 
         stack = DummyStack(another_res=rsrc())
-        ref = cfn_funcs.ResourceRef(stack, 'get_resource',
+        ref = hot_funcs.GetResource(stack, 'get_resource',
                                     'another_res')
         data = {
             'far': [{'red': ref}],
@@ -544,6 +547,26 @@ class TestTranslationRule(common.HeatTestCase):
         rule.execute_rule()
         self.assertEqual(data, props.data)
 
+    def test_resolve_rule_list_strings(self):
+        client_plugin, schema = self._test_resolve_rule()
+        data = {'far': ['one', 'rose']}
+        schema = {'far': properties.Schema(
+            properties.Schema.LIST,
+            schema=properties.Schema(
+                properties.Schema.STRING
+            )
+        )}
+        props = properties.Properties(schema, data)
+        rule = translation.TranslationRule(
+            props,
+            translation.TranslationRule.RESOLVE,
+            ['far'],
+            client_plugin=client_plugin,
+            finder='find_name_id')
+
+        rule.execute_rule()
+        self.assertEqual(['yellow', 'pink'], props.get('far'))
+
     def test_resolve_rule_list_empty(self):
         client_plugin, schema = self._test_resolve_rule(is_list=True)
         data = {
@@ -585,7 +608,7 @@ class TestTranslationRule(common.HeatTestCase):
             pass
 
         stack = DummyStack(another_res=rsrc())
-        ref = cfn_funcs.ResourceRef(stack, 'get_resource',
+        ref = hot_funcs.GetResource(stack, 'get_resource',
                                     'another_res')
         data = {'far': ref}
         props = properties.Properties(schema, data)
@@ -784,50 +807,6 @@ class TestTranslationRule(common.HeatTestCase):
         self.assertEqual(['white', 'roses', 'chrysanthemums'],
                          props.get('far'))
 
-    def test_property_no_translation_removed_function(self):
-        """Test case when list property with sub-schema takes json param."""
-        schema = {
-            'far': properties.Schema(properties.Schema.LIST,
-                                     schema=properties.Schema(
-                                         properties.Schema.MAP,
-                                         schema={
-                                             'bar': properties.Schema(
-                                                 properties.Schema.STRING,
-                                             ),
-                                             'dar': properties.Schema(
-                                                 properties.Schema.STRING
-                                             )
-                                         }
-                                     ))
-        }
-
-        class DummyStack(dict):
-            @property
-            def parameters(self):
-                return mock.Mock()
-
-        param = hot_funcs.Removed(DummyStack(json_far='json_far'),
-                                  'Ref',
-                                  'json_far')
-        param.parameters = {
-            'json_far': parameters.JsonParam(
-                'json_far',
-                {'Type': 'Json'},
-                '{"dar": "rad"}').value()}
-        data = {'far': [param]}
-
-        props = properties.Properties(schema, data)
-
-        rule = translation.TranslationRule(
-            props,
-            translation.TranslationRule.REPLACE,
-            ['far', 'bar'],
-            value_name='dar')
-
-        rule.execute_rule()
-
-        self.assertEqual([param], props.data.get('far'))
-
     def test_property_no_translation_if_user_parameter_missing(self):
         """Test translation in the case of missing parameter"""
         schema = {
@@ -864,3 +843,190 @@ class TestTranslationRule(common.HeatTestCase):
         # ensure that translation rule was not applied
         self.assertEqual({'source': param, 'destination': ''},
                          data)
+
+    def test_list_list_add_translation_rule(self):
+        schema = {
+            'far': properties.Schema(
+                properties.Schema.LIST,
+                schema=properties.Schema(
+                    properties.Schema.MAP,
+                    schema={
+                        'bar': properties.Schema(
+                            properties.Schema.LIST,
+                            schema=properties.Schema(properties.Schema.STRING)
+                        ),
+                        'car': properties.Schema(properties.Schema.STRING)
+                    }
+                )
+            )
+        }
+
+        data = {'far': [{'bar': ['shar'], 'car': 'man'}, {'car': 'first'}]}
+
+        props = properties.Properties(schema, data)
+
+        rule = translation.TranslationRule(
+            props,
+            translation.TranslationRule.ADD,
+            ['far', 'bar'],
+            value_name='car'
+        )
+        rule.execute_rule()
+
+        self.assertIn({'bar': ['shar', 'man'], 'car': 'man'}, props.get('far'))
+        self.assertIn({'bar': ['first'], 'car': 'first'}, props.get('far'))
+
+    def test_replace_rule_map_with_custom_value_path(self):
+        schema = {
+            'far': properties.Schema(
+                properties.Schema.MAP,
+                schema={
+                    'red': properties.Schema(
+                        properties.Schema.STRING
+                    )
+                }
+            ),
+            'bar': properties.Schema(
+                properties.Schema.MAP
+            )}
+
+        data = {
+            'far': {},
+            'bar': {'red': 'dak'}
+        }
+        props = properties.Properties(schema, data)
+
+        rule = translation.TranslationRule(
+            props,
+            translation.TranslationRule.REPLACE,
+            ['far', 'red'],
+            value_path=['bar'],
+            custom_value_path=['red']
+        )
+        rule.execute_rule()
+
+        self.assertEqual({'red': 'dak'}, props.get('far'))
+        self.assertEqual({}, props.get('bar'))
+
+    def test_replace_rule_list_with_custom_value_path(self):
+        schema = {
+            'far': properties.Schema(
+                properties.Schema.LIST,
+                schema=properties.Schema(
+                    properties.Schema.MAP,
+                    schema={
+                        'red': properties.Schema(
+                            properties.Schema.STRING
+                        ),
+                        'blue': properties.Schema(
+                            properties.Schema.MAP
+                        )
+                    }
+                )
+            )}
+
+        data = {
+            'far': [{'blue': {'black': {'white': 'daisy'}}},
+                    {'red': 'roses'}]
+        }
+        props = properties.Properties(schema, data)
+
+        rule = translation.TranslationRule(
+            props,
+            translation.TranslationRule.REPLACE,
+            ['far', 'red'],
+            value_name='blue',
+            custom_value_path=['black', 'white']
+        )
+        rule.execute_rule()
+
+        self.assertEqual([{'red': 'daisy', 'blue': {'black': {}}},
+                          {'blue': None, 'red': 'roses'}],
+                         props.get('far'))
+
+    def test_add_rule_list_with_custom_value_path(self):
+        schema = {
+            'far': properties.Schema(
+                properties.Schema.LIST,
+                schema=properties.Schema(
+                    properties.Schema.MAP,
+                    schema={
+                        'red': properties.Schema(
+                            properties.Schema.LIST,
+                            schema=properties.Schema(properties.Schema.STRING)
+                        ),
+                        'blue': properties.Schema(
+                            properties.Schema.MAP
+                        )
+                    }
+                )
+            )}
+
+        data = {
+            'far': [{'blue': {'black': {'white': 'daisy', 'check': ['one']}}},
+                    {'red': ['roses']}]
+        }
+        props = properties.Properties(schema, data)
+
+        rule = translation.TranslationRule(
+            props,
+            translation.TranslationRule.ADD,
+            ['far', 'red'],
+            value_name='blue',
+            custom_value_path=['black', 'check']
+        )
+        rule.execute_rule()
+
+        self.assertEqual([{'red': ['one'],
+                           'blue': {'black': {'white': 'daisy',
+                                              'check': ['one']}}},
+                          {'blue': None, 'red': ['roses']}],
+                         props.get('far'))
+
+        # check whether if data will contain list-type property to add
+        data = {
+            'far': [{'red': ['roses'], 'blue': {'black': {'check': ['two']}}}]}
+        props = properties.Properties(schema, data)
+        rule.properties = props
+        rule.execute_rule()
+        self.assertEqual([{'red': ['roses', 'two'],
+                           'blue': {'black': {'check': ['two']}}}],
+                         props.get('far'))
+
+    def test_list_list_error_translation_rule(self):
+        schema = {
+            'far': properties.Schema(
+                properties.Schema.LIST,
+                schema=properties.Schema(
+                    properties.Schema.MAP,
+                    schema={
+                        'car': properties.Schema(properties.Schema.STRING),
+                        'dar': properties.Schema(properties.Schema.STRING),
+                    }
+                )
+            ),
+            'bar': properties.Schema(
+                properties.Schema.LIST,
+                schema=properties.Schema(
+                    properties.Schema.MAP,
+                    schema={
+                        'car': properties.Schema(properties.Schema.STRING),
+                        'dar': properties.Schema(properties.Schema.STRING),
+                    }
+                )
+            ),
+        }
+
+        data = {'far': [{'car': 'man'}], 'bar': [{'dar': 'check'}]}
+
+        props = properties.Properties(schema, data)
+
+        rule = translation.TranslationRule(
+            props,
+            translation.TranslationRule.REPLACE,
+            ['far'],
+            value_path=['bar', 'car']
+        )
+        ex = self.assertRaises(ValueError, rule.execute_rule)
+        self.assertEqual('Cannot use value_path for properties inside '
+                         'list-type properties', six.text_type(ex))
